/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2009. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.repository.web.ui.internal.admin.AdminApplication");

dojo.require("jazz.app._JazzApplication");
dojo.require("com.ibm.team.repository.web.client.init.InitializationData");
dojo.require("com.ibm.team.repository.web.client.internal.RepositoryClient");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.client.internal.AdminClient");

dojo.require("net.jazz.ajax.ui.PlatformUI");
dojo.require("net.jazz.ajax.ui.internal.PageRegistry");
dojo.require("com.ibm.team.repository.web.ui.internal.LicenseInfoWidget"); //$NON-NLS-1$
dojo.require("com.ibm.team.repository.web.ui.internal.about.AboutJazzTeamServer");
dojo.require("com.ibm.team.repository.web.ui.internal.admin.NotAuthorizedView");
dojo.require("com.ibm.team.repository.web.transport.ServiceRequest");
dojo.require("com.ibm.team.repository.web.transport.TeamServerClient");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.requireLocalization("com.ibm.team.repository.web.ui.internal.admin.server", "AdminApplicationMessages"); //$NON-NLS-1$ //$NON-NLS-2$

var _JazzApplication          = jazz.app._JazzApplication;
var InitializationData      = com.ibm.team.repository.web.client.init.InitializationData;
var RepositoryClient 		= com.ibm.team.repository.web.client.internal.RepositoryClient;
var ServiceResponseHandler	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var ServiceRequest = com.ibm.team.repository.web.transport.ServiceRequest;
var TeamServerClient = com.ibm.team.repository.web.transport.TeamServerClient;
var AdminClient = com.ibm.team.repository.web.client.internal.AdminClient;
var getAuthenticatedUserId = com.ibm.team.repository.web.client.session.getAuthenticatedUserId;
var X_AUTH_MSG					= "X-com-ibm-team-repository-web-auth-msg";
var SERVICE_URI = "com.ibm.team.process.internal.common.service.IProcessRestService";
var PageRegistry = net.jazz.ajax.ui.internal.PageRegistry;
var LicenseInfoWidget = com.ibm.team.repository.web.ui.internal.LicenseInfoWidget;
var Session = com.ibm.team.repository.web.client.session;
var PlatformUI = net.jazz.ajax.ui.PlatformUI;
var messages = dojo.i18n.getLocalization("com.ibm.team.repository.web.ui.internal.admin.server", "AdminApplicationMessages"); //$NON-NLS-1$ //$NON-NLS-2$

dojo.declare("com.ibm.team.repository.web.ui.internal.admin.AdminApplication", _JazzApplication, {
	constructor: function() {
		this.getUserRoles();
		dojo.addClass(document.body,"com-ibm-team-repository-web-admin-body");		
	},	
	
	_fetchInitData: function (){
		var srh = new ServiceResponseHandler(this, "_handleInitData", "_fetchInitDataFailed");
		RepositoryClient.getInitializationData(srh);
	},
	
	getUserRoles: function () {
		var srh= new ServiceResponseHandler(this, "authRequestPassed", "authRequestFailed");		
		AdminClient.getUserRoles(srh);
	},
	
	authRequestPassed: function(response) {
		if (response.userId) {
			dojo.setObject("com.ibm.team.repository.web.client.internal.AUTHENTICATED_USERID", response.userId);
		}
		var roles = response.roles;
		for (var i=0; i < roles.length; i++) {
			if (roles[i] === "JazzAdmins") {
				this._userIsAdmin = true;
				break;
			}
		}
		this._fetchInitData();
	},
	
	authRequestFailed: function(errorObject) {
		this.setupNoContributorApplicationUI();
		this.showNotAuthorizedError();
	},
	
	showNotAuthorizedError: function() {
		var notAuth = new com.ibm.team.repository.web.ui.internal.admin.NotAuthorizedView();
		this.onFailure(null, notAuth.domNode);
	},
		
	_handleInitData: function(initData) {
		InitializationData._load(initData);
		var contributor = InitializationData.get("com.ibm.team.repository.service.currentContributorInitializer"); 
		if (contributor != null) {
			dojo.setObject("com.ibm.team.repository.web.client.internal.AUTHENTICATED_CONTRIBUTOR", contributor.currentContributor);
			this.config.user = {
				name: contributor.currentContributor.name, 
				userId: contributor.currentContributor.userId,
				href: Session.getUserProfileLink(),
				menuProvider: dojo.hitch(this, this._userMenuProvider)
			};	
		} else {
			this._handleNoContributor();
		}
		this.config.showLoginLogout = true;
		
		var licenseInfoWidget = new LicenseInfoWidget();
		this.ui.bannerRightText.appendChild(licenseInfoWidget.domNode);	
	
		// store the configuration properties in global vars with corresponding names
		var configProperties = InitializationData.get("com.ibm.team.repository.service.configPropertyInitializer");
		for (var propName in configProperties) {
			var propVal = configProperties[propName];
			dojo.setObject(propName, propVal);
		}
		if (this._userIsAdmin == null || !this._userIsAdmin) {
			this._suppressAdminOnlyPages();
		} 
		
		this.config.buttons.push({
			label: messages.help,
			iconSrc: dojo.moduleUrl("jazz.app", "graphics/JazzUI/icons/help.png"),
			align: "right",
			menuProvider: dojo.hitch(this,this._helpMenuProvider)
		});
		this.config.footer = {
			rightLogo: {src: dojo.moduleUrl("jazz.app", "graphics/JazzUI/rtl_logo_sm.gif"), href: "http://www.ibm.com/software/rational/"}
		};
		this.config.contextSwitcher = {contextProvider: this._getProjectAreas, selectLabel: messages.selectProject, emptyLabel: messages.noProjects, onChange: this._selectContext};
		this.config.navbarItems.push({
			label: messages.admin,
			align: "right",
			rightPipe: true,
			selected: true
		});
		if (com.ibm.team.repository.web.logouturi) {
			this.config.logout = { href: com.ibm.team.repository.web.logouturi };
		}
		this.start();
	},
	
	_handleNoContributor: function () {
		// handle case where there is no DB so contributor isn't in init data
		var userId = dojo.getObject("com.ibm.team.repository.web.client.internal.AUTHENTICATED_USERID");
		if (userId) {
			this.config.user = {
				name: userId,
				userId: userId
			};
		} else {
			// fake out the Logout path since we don't know the unauthorized user
			this.config.user = {
				name: "",
				userId: ""
			};
		}
	},
	
	_selectContext: function(contextObj) {
		var curUrl = new dojo._Url(location.href);
		if (curUrl.query) {  //check for debug mode
			var query = "?" + curUrl.query;	
		} else {
			var query = "";
		}
		var encodedName = encodeURIComponent(contextObj.name);
		return net.jazz.ajax._contextRoot + "/web/projects/" + encodedName + query;
	},
	
	_fetchInitDataFailed: function(errorObject) {
		// If the user got this far, the user is authenticated as a member of a Jazz J2EE group but we can't access InitData
		this.setupNoContributorApplicationUI();
		
		// Forbidden users see unauth message
		if (errorObject.status === 403) {
			// this is probably an archived user or admin
			this.showNotAuthorizedError();
			return;
		}
		
		// If init data failed, the server must be in a bad state.  So show all pages to JazzAdmins only
		if ((this._userIsAdmin != null && this._userIsAdmin == true)) {
			this.start();
		} else {
			this.onFailure(errorObject);
		}
	},
	
	setupNoContributorApplicationUI: function () {
		this.config.buttons.push({
			label: messages.help,
			iconSrc: dojo.moduleUrl("jazz.app", "graphics/JazzUI/icons/help.png"),
			align: "right",
			menuProvider: dojo.hitch(this,this._helpMenuProvider)
		});
		
		this._handleNoContributor();
		this.config.showLoginLogout = true;
	},
	
	_suppressAdminOnlyPages: function() {
		dojo.setObject("com.ibm.team.repository.admin.suppressPage", true);
		var suppressedPages = [];
		dojo.setObject("com.ibm.team.repository.web.suppressedPages", {
			"com.ibm.team.repository.web.admin": suppressedPages 
		});
		dojo.setObject("com.ibm.team.repository.web.noAdminAuth", "not authorized");
		suppressedPages.push("com.ibm.team.repository.server");
		suppressedPages.push("com.ibm.team.repository.users");
		this.config.suppressedPages = suppressedPages;
	},

	getAdminPages: function (){
		var pageIDs = [];
		var pages = PageRegistry.getPages();
		dojo.forEach(pages, function(page){
			pageIDs.push(page.id);
		});
		return pageIDs;
	},
	_helpMenuProvider: function() {
		var menu = new dijit.Menu();
		dojo.addClass(menu.domNode,"jazz-app-Banner-helpmenu");
		var helpuri = com.ibm.team.repository.web.helpuri;
		if (helpuri) {
			this.helpuri = helpuri;
			menu.addChild(new dijit.MenuItem({label: messages.helpContents, iconClass: 'helpIcon', onClick: dojo.hitch(this,this._openHelpContents)}));
		}
		var about = dojo.string.substitute(messages.about, [this.productName]);
		menu.addChild(new dijit.MenuItem({label: about, onClick: dojo.hitch(this,this._openAboutBox)}));
		return menu;
	},
	
	_userMenuProvider: function() {
		var menu = new dijit.Menu();
		dojo.addClass(menu.domNode, "jazz-app-loginLogoutArea-userMenu");
		var menuItem = new dijit.MenuItem({
			label: messages.editProfile, 
			iconClass: 'userIcon',
			onClick: function() {
				if (PlatformUI.getWorkbench().shouldVetoNavigation() === false) {
					location.href = Session.getUserProfileLink();
				}
			}}
		);
		menu.addChild(menuItem);
		return menu;
	},	
	
	_openHelpContents: function(event) {
		if (this.helpuri)
			window.open(this.helpuri,'help');
	},
	_openAboutBox: function(){
		var about = dojo.string.substitute(messages.about, [this.productName]);
		new com.ibm.team.repository.web.ui.internal.about.AboutJazzTeamServer({dialogTitle: about});
	},
	_getProjectAreas: function (dfd) {
		var srh = new ServiceResponseHandler(dfd, "callback", "errback");
		var authContribId = getAuthenticatedUserId();
		var serviceRequest = new ServiceRequest(SERVICE_URI, "getAllProjectAreas", {hideArchivedProjects: true, userId: authContribId});
		TeamServerClient.invokeService(serviceRequest, srh);
	}
});

var AdminWorkbench = com.ibm.team.repository.web.ui.internal.admin.AdminApplication;

})();
