/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2008. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("net.jazz.ajax.service.ui.internal.userdata.UserDataEditor");

dojo.require("net.jazz.ajax.ui.MappingUI");
dojo.require("net.jazz.ajax.ui.PlatformUI");
dojo.require("net.jazz.ajax.ui.Workbench");
dojo.require("net.jazz.ajax.service.ui.userdata.util");

dojo.require("jazz.client.xhr");

var PlatformUI = net.jazz.ajax.ui.PlatformUI;

function getTagString(entry) {
	var tagString = "";
	if (entry["userdata:tagArray"]) {
		var tags = [];
		for (var i=0; i < entry["userdata:tagArray"].length; i++) {
			tags.push(entry["userdata:tagArray"][i].value);
		}
		tagString = tags.join(", ");
	} else if (entry["userdata:tag"]) {
		tagString = entry["userdata:tag"].value;
	}
	return tagString;
}

dojo.declare("net.jazz.ajax.service.ui.internal.userdata.UserDataEditor", [dijit._Widget, dijit._Templated], {
	templatePath: dojo.moduleUrl("net.jazz.ajax.service", "ui/internal/userdata/templates/UserDataEditor.html"),
	
	postCreate: function() {
		this.inherited(arguments);
		var pathInfo = net.jazz.ajax.ui.MappingUI._getPathInfo();
		net.jazz.ajax.service.ui.userdata.util.addHistory({
			uri: pathInfo
		});
		this.editorFields = [
			this.titleField,
			this.commentsField,
			this.tagsField,
			this.folderField,
			this.sortKeyField
		];
		dojo.forEach(this.editorFields, dojo.hitch(this, function (field) {
			this.connect(field, "onchange", "handleChange");
			this.connect(field, "onkeyup", "handleChange");
		}));
	},
	
	processResponse: function (response) {
		this.userData = {};
		var tagString = getTagString(response["userdata:tags"]);
		this.userData = {
			uri: response.link.href,
			title: response.title.value,
			comments: response["userdata:comments"].value,
			tags: tagString,
			folder: response["userdata:folder"] ? response["userdata:folder"].value : ""
		};
		this.populate();
		return response;
	},
	
	processResponseErr: function (response, type) {
		// TODO - display user-friendly error message
		alert("An error occurred retrieving your " + type + ": " + err);
	},
	
	populate: function () {
		dojox.data.dom.removeChildren(this.pathField);
		this.pathField.appendChild(document.createTextNode(this.userData.uri || ""));
		this.titleField.value = this.userData.title || "";
		this.titleField.origValue = this.userData.title || "";
		this.commentsField.value = this.userData.comments || "";
		this.commentsField.origValue = this.userData.comments || "";
		this.tagsField.value = this.userData.tags || "";
		this.tagsField.origValue = this.userData.tags || "";
		this.folderField.value = this.userData.folder || "";
		this.folderField.origValue = this.userData.folder || "";
		this.sortKeyField.value = this.userData.sortKey || "";
		this.sortKeyField.origValue = this.userData.sortKey || "";
		this.saveButton.disabled = true;
	},
	
	handleChange: function (e) {
		if (e.target.origValue != e.target.value) {
			this.saveButton.disabled = false;
		} else {
			var dirty = false;
			for (var i=0; i < this.editorFields.length; i++) {
				if (this.editorFields[i].origValue != this.editorFields[i].value) {
					dirty = true;
					break;
				}
			}
			this.saveButton.disabled = !dirty;
		}
	}
});
})();